TAMES Search

# Supreme Court

Site Search
Document Search Criteria
Case Search Document Search
All Courts

Supreme Court | 7th Court
Criminal Appeals | 8th Court
1st Court | 9th Court
2nd Court | 10th Court
3rd Court | 11th Court
4th Court | 12th Court
5th Court | 13th Court
6th Court | 14th Court

Selection Criteria
Text String To Search:
Phonic Stemming
Fuzzy
From Date:

| Open the calendar popup.
<< | < | September 2015 | > | >>
| S | M | T | W | T | F | S
--- | --- | --- | --- | --- | --- | --- | ---
36 | 30 | 31 | 1 | 2 | 3 | 4 | 5
37 | 6 | 7 | 8 | 9 | 10 | 11 | 12
38 | 13 | 14 | 15 | 16 | 17 | 18 | 19
39 | 20 | 21 | 22 | 23 | 24 | 25 | 26
40 | 27 | 28 | 29 | 30 | 1 | 2 | 3
41 | 4 | 5 | 6 | 7 | 8 | 9 | 10

to

| Open the calendar popup.
<< | < | September 2015 | > | >>
| S | M | T | W | T | F | S
--- | --- | --- | --- | --- | --- | --- | ---
36 | 30 | 31 | 1 | 2 | 3 | 4 | 5
37 | 6 | 7 | 8 | 9 | 10 | 11 | 12
38 | 13 | 14 | 15 | 16 | 17 | 18 | 19
39 | 20 | 21 | 22 | 23 | 24 | 25 | 26
40 | 27 | 28 | 29 | 30 | 1 | 2 | 3
41 | 4 | 5 | 6 | 7 | 8 | 9 | 10

Select media file type(s) to search:
All Opinion Order Other
Examples: apple pie and pear | apple pie or pear | apple pie w/5 pear | apple not w/12 pear | apple and not pear | wildcard w/5 match* |

1 2 3 4 5 6 131 items in 6 pages
Hits | Date | Summary | Document Type | Case Number | Appellate Court
--- | --- | --- | --- | --- | ---
1 2 3 4 5 6 131 items in 6 pages
0 | 06/17/2015 |  | Opinion | PD-0501-14 | COSCCA
0 | 06/17/2015 |  | Opinion | WR-81,875-01 | COSCCA
0 | 07/01/2015 |  | Opinion | WR-82,941-01 | COSCCA
0 | 07/01/2015 |  | Opinion | PD-0474-14 | COSCCA
0 | 06/10/2015 |  | Opinion | WR-82,563-01 | COSCCA
0 | 06/17/2015 |  | Opinion | WR-82,919-01 | COSCCA
0 | 06/24/2015 |  | Opinion | PD-1790-13 | COSCCA
0 | 07/01/2015 |  | Opinion | WR-82,426-03 | COSCCA
0 | 06/17/2015 |  | Opinion | WR-76,781-01 | COSCCA
0 | 06/24/2015 |  | Opinion | PD-1792-13 | COSCCA
0 | 06/24/2015 |  | Opinion | PD-1793-13 | COSCCA
0 | 06/10/2015 |  | Opinion | WR-81,806-03 | COSCCA
0 | 06/24/2015 |  | Opinion | PD-1791-13 | COSCCA
0 | 06/17/2015 |  | Opinion | PD-0501-14 | COSCCA
0 | 06/24/2015 |  | Opinion | WR-79,465-01 | COSCCA
0 | 06/24/2015 |  | Opinion | PD-1792-13 | COSCCA
0 | 06/24/2015 |  | Opinion | WR-81,078-04 | COSCCA
0 | 07/01/2015 |  | Opinion | WR-20,460-02 | COSCCA
0 | 06/24/2015 |  | Opinion | PD-1790-13 | COSCCA
0 | 07/01/2015 |  | Opinion | PD-1071-14 | COSCCA
0 | 07/01/2015 |  | Opinion | WR-81,830-01 | COSCCA
0 | 06/10/2015 |  | Opinion | WR-81,806-04 | COSCCA
0 | 07/01/2015 |  | Opinion | PD-0421-14 | COSCCA
0 | 06/24/2015 |  | Opinion | PD-1791-13 | COSCCA
0 | 06/24/2015 |  | Opinion | PD-1791-13 | COSCCA

NOTE: This information is compiled and made available as a public service by The Supreme Court of Texas, the Texas Court of Criminal Appeals and the Courts of Appeals. However, these courts make no warranty as to the accuracy, reliability, or completeness of the information and are not responsible for any errors or omissions or for results obtained from the use of the information. Distribution of the information does not constitute such a warranty. Use of the information is the sole responsibility of the user.
Also, note that neither TCO nor OCA have or maintain records on individual trial court cases but we maintain the following list of searchable county systems. You would need to contact the court DIRECTLY for specific case information, see our online Judicial Directory [or view pdf version] for contact information.
To view or print PDF files you must have the Adobe Acrobat® reader. This software may be obtained without charge from Adobe. Download the reader from the Adobe Web site.

131